function [y,ocena]=horneroc(a,x)

% HORNER(a,x) po Hornerjevem pravilu izracuna vrednost 
%   polinoma v tocki, hkrati pa se oceno za zaokrozitveno napako
%
% Argumenti:
%   a : vektor koeficientov polinoma
%   x : tocka, v kateri racunamo vrednost polinoma (lahko tudi vektor tock)
%
% Rezultat:
%   y : vrednost polinoma p v tocki x
%   ocena : ocena za zaokrozitveno napako izracunane vrednosti p(x)

% Bor Plestenjak 2010

n = length(a);
p = a(1)*ones(1,length(x));
ocena = abs(a(1))*ones(1,length(x));
for k = 2:n
   p = x.*p+a(k);
   ocena = abs(x).*ocena+abs(a(k));
end

y = p;
ocena = 2*n*ocena*eps;
